Attribute VB_Name = "MouseApiFunctions"
'********************************************************************
'   SystemTrayApi.bas
'
'   Purpose:
'       Contains all the API functions and functions used
'       for the mouse movement and clicking.
'********************************************************************
Public Type POINTAPI
   x As Long
   y As Long
End Type

' Win32 API declarations for the mouse movement and clicking
Public Declare Function CloseWindow Lib "user32" (ByVal hWnd As Long) As Long
Public Declare Function GetForegroundWindow Lib "user32" () As Long
Public Declare Function SetForegroundWindow Lib "user32" (ByVal hWnd As Long) As Long
Public Declare Sub GetCursorPos Lib "user32" (lpPoint As POINTAPI)
Public Declare Sub SetCursorPos Lib "user32" (ByVal x As Long, ByVal y As Long)
Public Declare Function SetFocus Lib "user32" (ByVal hWnd As Long) As Long
Public Declare Sub mouse_event Lib "user32" (ByVal dwFlags As Long, ByVal dx As Long, _
        ByVal dy As Long, ByVal cButtons As Long, ByVal dwExtraInfo As Long)
Public Declare Function FindWindow Lib "user32" Alias "FindWindowA" (ByVal lpClassName As String, _
        ByVal lpWindowName As String) As Long
Public Declare Function SendMessage Lib "user32" Alias "SendMessageA" (ByVal hWnd As Long, _
        ByVal wMsg As Long, ByVal wParam As Long, ByVal lParam As Long) As Long
Public Declare Sub Sleep Lib "kernel32" (ByVal dwMilliseconds As Long)



Const MOUSE_MOVE = &H1
Const MOUSE_LEFTDOWN = &H2
Const MOUSE_LEFTUP = &H4
Const MOUSE_RIGHTDOWN = &H8
Const MOUSE_RIGHTUP = &H10
Const MOUSE_MIDDLEDOWN = &H20
Const MOUSE_MIDDLEUP = &H40
Const MOUSE_ABSOLUTE = &H8000
Public Sub MoveMouseRight()
'****************************************************************************
'MoveMouseRight
'
'Purpose:   Moves the mouse right for the boxed movement method
'
'Input:     None
'
'Output:    None
'****************************************************************************

    Dim point As POINTAPI
    
    Call GetCursorPos(point)
    point.x = point.x + 2
    SetCursorPos point.x, point.y
    
End Sub
Public Sub MoveMouseLeft()
'****************************************************************************
'MoveMouseLeft
'
'Purpose:   Moves the mouse left for the boxed movement method
'
'Input:     None
'
'Output:    None
'****************************************************************************

    Dim point As POINTAPI
    
    Call GetCursorPos(point)
    point.x = point.x - 2
    SetCursorPos point.x, point.y
    
End Sub
Public Sub MoveMouseDown()
'****************************************************************************
'MoveMouseDown
'
'Purpose:   Moves the mouse down for the boxed movement method
'
'Input:     None
'
'Output:    None
'****************************************************************************

    Dim point As POINTAPI
    
    Call GetCursorPos(point)
    point.y = point.y + 2
    SetCursorPos point.x, point.y
    
End Sub
Public Sub MoveMouseUp()
'****************************************************************************
'MoveMouseUp
'
'Purpose:   Moves the mouse up for the boxed movement method
'
'Input:     None
'
'Output:    None
'****************************************************************************

    Dim point As POINTAPI
    
    Call GetCursorPos(point)
    point.y = point.y - 2
    SetCursorPos point.x, point.y
    
End Sub
Public Sub MouseDown()
'****************************************************************************
'MouseDown
'
'Purpose:   Sends an API message for the mouse to left click down
'
'Input:     None
'
'Output:    None
'****************************************************************************

     Dim point As POINTAPI
     Call GetCursorPos(point)
     SetCursorPos point.x, point.y
     mouse_event MOUSE_ABSOLUTE + MOUSE_LEFTDOWN, point.x, point.y, 0, 0
End Sub
Public Sub MouseUp()
'****************************************************************************
'MouseDown
'
'Purpose:   Sends an API message for the mouse to right click up
'
'Input:     None
'
'Output:    None
'****************************************************************************

    Dim point As POINTAPI
    Call GetCursorPos(point)
    mouse_event MOUSE_ABSOLUTE + MOUSE_LEFTUP, point.x, point.y, 0, 0
End Sub
Public Sub MouseRightClick()
'****************************************************************************
'MouseRightClick
'
'Purpose:   Sends an API message for the mouse to right click
'
'Input:     None
'
'Output:    None
'****************************************************************************

    Dim point As POINTAPI
    Call GetCursorPos(point)
    SetCursorPos point.x, point.y
    SetForegroundWindow 0
    mouse_event MOUSE_ABSOLUTE + MOUSE_RIGHTDOWN + MOUSE_RIGHTUP, point.x, point.y, 0, 0
End Sub
Public Sub MouseLeftClick()
'****************************************************************************
'MouseLeftClick
'
'Purpose:   Sends an API message for the mouse to left click
'
'Input:     None
'
'Output:    None
'****************************************************************************
    
    Dim point As POINTAPI
    Dim xdif As Integer
    Dim ydif As Integer
    Call GetCursorPos(point)
    
    SetCursorPos point.x, point.y
    SetForegroundWindow 0
    mouse_event MOUSE_ABSOLUTE + MOUSE_LEFTDOWN + MOUSE_LEFTUP, point.x, point.y, 0, 0

End Sub

Public Sub MoveMouse_Expediential(oldx As Integer, oldy As Integer, cx As Integer, cy As Integer, buffersize As Integer)
'****************************************************************************
'MoveMouse_Expediential
'
'Purpose:   Moves the mouse in an expediential fassion.
'
'Input:     oldx        'old x pixel cordinate
'           oldy        'old y pixel cordinate
'           cx          'current x pixel cordinate
'           cy          'current y pixel cordinate
'           buffersize  'the size of the movement before the algorithm kicks in
'
'Output:    None
'****************************************************************************

    Dim point As POINTAPI
    Dim xdif As Integer
    Dim ydif As Integer
    xdif = cx - oldx
    xdif = xdif * -1
    ydif = cy - oldy
    ydif = ydif * -1
    If oldx <> 999 And oldy <> 999 Then
        Call GetCursorPos(point)
        If xdif < 0 Then
            If xdif > (buffersize * -1) Then
                point.x = point.x - Abs(xdif)
            Else
                point.x = point.x - (Abs(xdif) ^ 2)
            End If
        Else
            If xdif < buffersize Then
                point.x = point.x + Abs(xdif)
            Else
                point.x = point.x + (Abs(xdif) ^ 2)
            End If
        End If
        If ydif < 0 Then
            If ydif > (buffersize * -1) Then
                point.y = point.y - Abs(ydif)
            Else
                point.y = point.y - (Abs(xdif) ^ 2)
            End If
        Else
            If ydif < buffersize Then
                point.y = point.y + Abs(ydif)
            Else
                point.y = point.y + (Abs(xdif) ^ 2)
            End If
        End If
        SetCursorPos point.x, point.y
    End If
    
End Sub
Public Sub MoveMouse_Linear(oldx As Integer, oldy As Integer, cx As Integer, cy As Integer, sensitivity As Integer, buffersize As Integer)
'****************************************************************************
'MoveMouse_Linear
'
'Purpose:   Moves the mouse in an expediential fassion.
'
'Input:     oldx        'old x pixel cordinate
'           oldy        'old y pixel cordinate
'           cx          'current x pixel cordinate
'           cy          'current y pixel cordinate
'           buffersize  'the size of the movement before the algorithm kicks in
'           sensitivity 'how manys time the differnce the mouse should move.
'
'Output:    None
'****************************************************************************

    Dim point As POINTAPI
    Dim xdif As Integer
    Dim ydif As Integer
    xdif = cx - oldx
    xdif = xdif * -1
    ydif = cy - oldy
    ydif = ydif * -1
    If oldx <> 999 And oldy <> 999 Then
        Call GetCursorPos(point)
        If xdif < 0 Then
            If xdif > (buffersize * -1) Then
                point.x = point.x - Abs(xdif)
            Else
                point.x = point.x - Abs(xdif * sensitivity)
            End If
        Else
            If xdif < buffersize Then
                point.x = point.x + Abs(xdif)
            Else
                point.x = point.x + Abs(xdif * sensitivity)
            End If
        End If
        If ydif < 0 Then
            If ydif > (buffersize * -1) Then
                point.y = point.y - Abs(ydif)
            Else
                point.y = point.y - Abs(ydif * sensitivity)
            End If
        Else
            If ydif < buffersize Then
                point.y = point.y + Abs(ydif)
            Else
                point.y = point.y + Abs(ydif * sensitivity)
            End If
        End If
        SetCursorPos point.x, point.y
    End If
    
End Sub





