Attribute VB_Name = "SystemTrayApiFunctions"
'********************************************************************
'   SystemTrayApi.bas
'
'   Purpose:
'       Contains all the windows API functions and functions for
'       adding and deleting a system tray icon.
'********************************************************************

'Variable to pass to the Shell_NotiyIcon function
Private Type NOTIFYICONDATA
    cbSize As Long
    hWnd As Long
    uId As Long
    uFlags As Long
    uCallBackMessage As Long
    hIcon As Long
    szTip As String * 64
End Type

'Constants for the Shell_NotifyIcon function
Private Const NIM_ADD = &H0
Private Const NIM_MODIFY = &H1
Private Const NIM_DELETE = &H2

Private Const WM_MOUSEMOVE = &H200

Private Const NIF_MESSAGE = &H1
Private Const NIF_ICON = &H2
Private Const NIF_TIP = &H4

Private Const WM_LBUTTONDBLCLK = &H203
Private Const WM_LBUTTONDOWN = &H201
Private Const WM_LBUTTONUP = &H202
Private Const WM_RBUTTONDBLCLK = &H206
Private Const WM_RBUTTONDOWN = &H204
Private Const WM_RBUTTONUP = &H205

Dim nID As NOTIFYICONDATA
Private Declare Function Shell_NotifyIcon Lib "shell32" Alias "Shell_NotifyIconA" (ByVal dwMessage As Long, pnid As NOTIFYICONDATA) As Boolean

Public Sub AddIcon(ByVal ToolTip As String, programform As Form)
'****************************************************************************
'AddIcon
'
'Purpose:   Adds a system tray icon in the taskbar
'
'Input:     ToolTip
'           programform
'
'Output:    None
'****************************************************************************
    On Error GoTo ErrorHandler
    'Add icon to system tray
    With nID
        .cbSize = Len(nID)
        .hWnd = programform.hWnd
        .uId = vbNull
        .uFlags = NIF_ICON Or NIF_TIP Or NIF_MESSAGE
        .uCallBackMessage = WM_MOUSEMOVE
        .hIcon = programform.Icon
        .szTip = ToolTip & vbNullChar
    End With
    Call Shell_NotifyIcon(NIM_ADD, nID) 'add the icon in the taskbar
    
Exit Sub

ErrorHandler: 'Display error message

   MsgBox "Error occured check error file for details. "
  

End Sub

Public Sub MouseMoveCheck(programform As Form, x As Single)
'****************************************************************************
'MouseMoveCheck
'
'Purpose:   Plays with the systemtrya icon, allows the form to
'           be hidden in the system tray. Also allows the program
'           be preloaded in the system tray
'
'Input:     ToolTip
'           x
'
'Output:    None
'****************************************************************************

    Dim msg As Long

   'Respond to user interaction
    msg = x / Screen.TwipsPerPixelX

    Select Case msg
        Case WM_LBUTTONDBLCLK
            'nothing
        Case WM_LBUTTONDOWN
            'nothing
        Case WM_LBUTTONUP
            If programform.WindowState = vbMinimized Then
                programform.WindowState = vbNormal
                programform.Show
            Else
                programform.WindowState = vbMinimized
                programform.Hide
            End If
        Case WM_RBUTTONDBLCLK
            'nothing
        Case WM_RBUTTONDOWN
            'nothing
        Case WM_RBUTTONUP
            'Probably should put the menu here if you want one.
            programform.PopupMenu smenu
        End Select
End Sub
Public Sub DeleteSystemTrayIcon()
'****************************************************************************
'MouseMoveCheck
'
'Purpose:   Deletes a system tray icon in the taskbar
'
'Input:     None
'
'Output:    None
'****************************************************************************

    Call Shell_NotifyIcon(NIM_DELETE, nID)
End Sub
